@@ -39,16 +39,6 @@ kGridSiteWorkDir = '/srv/workDir/'
 ############    Grid Site Related      ##############
 #####################################################
 
-try:
-    from hpogrid.utils.grid_site_info import GridSiteInfo
-    kGPUGridSiteList = GridSiteInfo.list_sites()
-    kGPUGridSiteList += ['ANALY_CERN-PTEST','ANY', 'UKI-NORTHGRID-MAN-HEP']
-except:
-    kGPUGridSiteList = None
-
-kStableGPUGridSiteList = ['ANALY_MANC_GPU_TEST', 'ANALY_MWT2_GPU', 'DESY-HH_GPU']
-kDefaultGridSite = ','.join(kStableGPUGridSiteList)
-
 kGPUSiteNGPU = {
     'ANALY_MANC_GPU_TEST': 10, #single queue, no submission parameters, 1 GPU per job
     'ANALY_QMUL_GPU_TEST': 6, # GPUNumber=x for now is hardcoded in the dev APF JDL,number of GPUs per job limited by cgroups, K80=2*K40, so total of 6 gpu slots avalable.
@@ -147,7 +137,7 @@ kConfigFormat = {
         'log_dir': {
             'required': False,
             'type': str,
-            'default': './log'
+            'default': None
         },
         'verbose': {
             'required': False,
@@ -179,7 +169,7 @@ kConfigFormat = {
         'site': {
             'required': False,
             'type': (list, str),
-            'default': kDefaultGridSite
+            'default': None
         },
         'container': {
             'required': False,
@@ -291,4 +281,21 @@ kDefaultModelParam = json.dumps(kConfigFormat['model']['param']['default'])
 
 kHPOGridMetadataFormat = ['project_name', 'metric', 'mode', 'task_time_s', 'result', 'hyperparameters', 'best_config', 'start_datetime', 'end_datetime', 'start_timestamp']
 
-kGridSiteMetadataFileName = 'userJobMetadata.json' #jobReport.json
\ No newline at end of file
+kGridSiteMetadataFileName = 'userJobMetadata.json' #jobReport.json
+
+
+#####################################################
+################    Deprecated      #################
+#####################################################
+
+'''
+try:
+    from hpogrid.utils.grid_site_info import GridSiteInfo
+    kGPUGridSiteList = GridSiteInfo.list_sites()
+    kGPUGridSiteList += ['ANALY_CERN-PTEST','ANY', 'UKI-NORTHGRID-MAN-HEP']
+except:
+    kGPUGridSiteList = None
+
+kStableGPUGridSiteList = ['ANALY_MANC_GPU_TEST', 'ANALY_MWT2_GPU', 'DESY-HH_GPU']
+kDefaultGridSite = ','.join(kStableGPUGridSiteList)
+'''
\ No newline at end of file
