@@ -6,6 +6,7 @@ import json
 import tempfile
 
 import hpogrid
+
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper, stylus
 from hpogrid.idds_interface.idds_utils import transpose_config
@@ -26,7 +27,7 @@ class GridHandler():
         parser.add_argument('-n','--n_jobs', type=int, help='number of jobs to submit',
             default=1)
         parser.add_argument('-s','--site', help='site to submit the job to '
-            '(this will override the grid config site setting)', choices=kGPUGridSiteList)
+            '(this will override the grid config site setting)', default=None)
         parser.add_argument('-t','--time', help='same as maxCpuCount in prun which '
             'specifies the maximum cpu time for a job (prevent being killed by'
             'looping job detection)', type=int, default=-1)
