@@ -280,15 +280,39 @@ class PandaTaskManager():
             filtered_data.append(params.copy())
             self.set_status_color(params)
             print(kStrf.format(**params))
-
-    def print_metadata(self, datasets):
-        for data in datasets:     
-            if 'jobs_metadata' in data:
-                print('INFO: Printing metadata for JediTaskID:',data['jeditaskid'])
-                print(next(iter(data['jobs_metadata'])))
+    @staticmethod
+    def extract_metadata(datasets):
+        metadata = {}
+        # loop over tasks
+        for task in datasets:
+            # check if jobs metadata exists in a dataset
+            if task.get('jobs_metadata',None):
+                task_id = task.get('jeditaskid', None)
+                if task_id is None:
+                    raise ValueError('Unable to extract jeditaskid from url response')
+                task_name = task.get('taskname', None)
+                if task_name is None:
+                    raise ValueError('Unable to extract taskname from url response')
+                metadata[task_id] = {'taskname': task_name, 'jobs_metadata':{} }
+                # loop over jobs in a task
+                for job_id in task['jobs_metadata']:
+                    # fill user job metadata from a job
+                    metadata[task_id]['jobs_metadata'][job_id] = task['jobs_metadata'][job_id].get('user_job_metadata', {})
+                        
+        return metadata
+    
+    @staticmethod
+    def print_metadata(datasets):
+        metadata = PandaTaskManager.extract_metadata(datasets)
+        for task_id in metadata:
+            print('INFO: Printing metadata for task: {} (JediTaskID: {})'.format(metadata[task_id]['taskname'], task_id))
+            for job_id in metadata[task_id]['jobs_metadata']:
+                print('Job ID: {}'.format(job_id))
+                print('User Job Metadata:\n{}\n'.format(metadata[task_id]['jobs_metadata'][job_id]))
 
     # filter task by jeditaskid range
-    def filter_range(self, datasets, frange):
+    @staticmethod
+    def filter_range(datasets, frange):
         r = frange.split('-')
         if frange[0] == '-':
             datasets = [ds for ds in datasets if int(ds['jeditaskid']) <= int(r[1])]
@@ -299,7 +323,8 @@ class PandaTaskManager():
         return datasets
     
     # filter task by status
-    def filter_status(self, datasets, status):
+    @staticmethod
+    def filter_status(datasets, status):
         if not isinstance(status, list):
             status = [status]
         datasets = [ds for ds in datasets if ds.get('status', None) in status]
@@ -330,10 +355,11 @@ class PandaTaskManager():
         datasets = self.query_tasks(**params)
         
         print('')
+        self.print_standard(datasets)
+        
         if args.metadata:
-            self.print_metadata(datasets)
-        else:
-            self.print_standard(datasets)
+            print('')
+            self.print_metadata(datasets)       
 
         if output:
             self.save_datasets(datasets, output, col=outcol)
@@ -343,16 +369,16 @@ class PandaTaskManager():
         return pbookCore.get_active_tasks()
 
     def kill(self, args):
-        taskid = int(args.jeditaskid)
-        self.pbook.kill(taskid)
+        task_id = int(args.jeditaskid)
+        self.pbook.kill(task_id)
 
     def retry(self, args):
-        taskid = int(args.jeditaskid)
-        self.pbook.retry(taskid)
+        task_id = int(args.jeditaskid)
+        self.pbook.retry(task_id)
 
     def killAndRetry(self, args):
-        taskid = int(args.jeditaskid)
-        self.pbook.killAndRetry(taskid)
+        task_id = int(args.jeditaskid)
+        self.pbook.killAndRetry(task_id)
 
 
 
