@@ -56,13 +56,13 @@ class HPOReport():
                 print('INFO: Expecting HPO project name "{}" but "{}" is received. '
                     'Result summary will be skipped.')
             return False
-        
+        ####################################################################################### 
         if (set(self.attrib['hyperparameters']) != set(data['hyperparameters'])):
             if self.verbose:
                 print('INFO: Inconsistent hyperparameter space. '
                         'Result summary will be skipped.')
             return False
-
+        #######################################################################################
         if (self.attrib['metric'] != data['metric']) or (self.attrib['mode'] != data['mode']):
             if self.verbose:
                 print('INFO: Inconsistent metric definition. '
@@ -95,8 +95,18 @@ class HPOReport():
         with open(fname, 'r') as json_file:
             data = json.load(json_file)
         return cls(data, verbose)
+    
+    @classmethod
+    def from_summary(cls, fname, verbose=True):
+        with open(fname, 'r') as json_file:
+            data = json.load(json_file)
+        instance = cls()
+        instance.data = data.pop('jobs', None)
+        instance.attrib = data
+        return instance
 
-    def merge_data(self, extra_columns=None, skip_time=True):
+    def merge_data(self, extra_columns=None, skip_time=True,
+                   metric_min=None, metric_max=None):
         merged_data = []
         for data in self.data:
             for index in data['result']:
@@ -112,9 +122,22 @@ class HPOReport():
         if skip_time:
             for data in merged_data:
                 data.pop('time_s')
+        df = pd.DataFrame(merged_data)
+        
+        if self.attrib['mode'] == 'min':
+            sort_ascending = True
+        elif self.attrib['mode'] == 'max':
+            sort_ascending = False
+
+        df = df.sort_values(by=self.attrib['metric'] , ascending=sort_ascending).reset_index(drop=True)
+        if metric_min is not None:
+            df = df[df[self.attrib['metric']] > metric_min]
+        if metric_max is not None:
+            df = df[df[self.attrib['metric']] < metric_max]
+        merged_data = df.to_dict('records')
         return merged_data
 
-    def save_json(self, fname, indent=2):
+    def to_summary(self, fname, indent=2):
         if not self._check_data():
             return None
         report = self.attrib
@@ -122,28 +145,28 @@ class HPOReport():
         with open(fname, 'w') as file:
             json.dump(report, file, indent=indent)
 
-    def to_json(self, fname, extra_columns=None, skip_time=True, indent=2):
+    def to_json(self, fname, extra_columns=None, skip_time=True, 
+                metric_min=None, metric_max=None, indent=2):
         if not self._check_data():
             return None
-        df = self.to_dataframe(extra_columns, skip_time)
+        data = self.merge_data(extra_columns, skip_time, 
+                               metric_min=metric_min,
+                               metric_max=metric_max)
         with open(fname, 'w') as output:
-            json.dump(df.to_dict(), output, indent=indent)
+            json.dump(data, output, indent=indent)
 
-    def to_dataframe(self, extra_columns=None, skip_time=True):
+    def to_dataframe(self, extra_columns=None, skip_time=True,
+                    metric_min=None, metric_max=None):
         if not self._check_data():
             return None
-        data = self.merge_data(extra_columns, skip_time)
+        data = self.merge_data(extra_columns, skip_time,
+                               metric_min=metric_min,
+                               metric_max=metric_max)                               
         df = pd.DataFrame(data)
-
-        if self.attrib['mode'] == 'min':
-            sort_ascending = True
-        elif self.attrib['mode'] == 'max':
-            sort_ascending = False
-
-        df = df.sort_values(by=self.attrib['metric'] , ascending=sort_ascending).reset_index(drop=True)
         return df
 
-    def to_mlflow(self, extra_columns=None, skip_time=True):
+    def to_mlflow(self, extra_columns=None, skip_time=True,
+                 metric_min=None, metric_max=None):
         if not self._check_data():
             return None
         from mlflow.tracking import MlflowClient
@@ -156,7 +179,9 @@ class HPOReport():
             extra_columns = ['start_timestamp']
         elif 'start_timestamp' not in extra_columns:
             extra_columns.append('start_timestamp')
-        merged_data = self.merge_data(extra_columns, skip_time=False)
+        merged_data = self.merge_data(extra_columns, skip_time=False, 
+                                       metric_min=metric_min,
+                                       metric_max=metric_max)
         for data in merged_data:
             start_time = int(data['start_timestamp']*1000)
             end_time = int((data['start_timestamp']+data['time_s'])*1000)
@@ -167,31 +192,40 @@ class HPOReport():
             client.log_metric(run_id, metric, data[metric])
             client.set_terminated(run_id, end_time=end_time)
             
-    def to_html(self, fname=None, extra_columns=None, skip_time=True):
+    def to_html(self, fname=None, extra_columns=None, skip_time=True,
+               metric_min=None, metric_max=None):
         if not self._check_data():
             return None
-        df = self.to_dataframe(extra_columns, skip_time)
+        df = self.to_dataframe(extra_columns, skip_time,
+                               metric_min=metric_min,
+                               metric_max=metric_max)                               
         html_text = df.to_html()
         if fname:
             with open(fname, 'w') as outfile:
                 outfile.write(html_text)
         return html_text
 
-    def to_parallel_coordinate_plot(self, fname=None, extra_columns=None, skip_time=True):
+    def to_parallel_coordinate_plot(self, fname=None, extra_columns=None, skip_time=True,
+                                   metric_min=None, metric_max=None):
         if not self._check_data():
             return None
         import hiplot as hip
-        merged_data = self.merge_data(extra_columns, skip_time)
+        merged_data = self.merge_data(extra_columns, skip_time, 
+                                       metric_min=metric_min,
+                                       metric_max=metric_max)
         html_text = hip.Experiment.from_iterable(merged_data).to_html()
         if fname:
             with open(fname, 'w') as outfile:
                 outfile.write(html_text)
         return html_text
 
-    def to_csv(self, fname, extra_columns=None, skip_time=True):
+    def to_csv(self, fname, extra_columns=None, skip_time=True,
+               metric_min=None, metric_max=None):
         if not self._check_data():
             return None
-        df = self.to_dataframe(extra_columns, skip_time)
+        df = self.to_dataframe(extra_columns, skip_time, 
+                               metric_min=metric_min,
+                               metric_max=metric_max)
         csv = df.to_csv(fname, encoding='utf-8')
         return csv
 
@@ -239,6 +273,10 @@ class HPOTaskHandle(HPOReport):
             help='output result as an mlflow tracker directory')
         parser.add_argument('-o', '--outname', default='hpo_result',
             help='output file name (excluding extension)')
+        parser.add_argument('--min', type=float, default=None,
+            help='filter results by minimum value of metric ')
+        parser.add_argument('--max', type=float, default=None,
+            help='filter results by maximum value of metric ')
         return parser
 
     def run_parser(self):
@@ -268,18 +306,21 @@ class HPOTaskHandle(HPOReport):
         self.parse_datasets(datasets, proj_name, extra_columns=extra_columns)
         self.show(extra_columns, skip_time)
 
+        bounds = {'metric_min':args.min, 'metric_max':args.max}
+        
         if args.summary:
-            self.save_json(outname+'_summary.json')
+            self.to_summary(outname+'_summary.json')
         if args.to_json:
-            self.to_json(outname+'.json', extra_columns, skip_time)
+            self.to_json(outname+'.json', extra_columns, skip_time, **bounds)
         if args.to_html:
-            self.to_html(outname+'.html', extra_columns, skip_time)
+            self.to_html(outname+'.html', extra_columns, skip_time, **bounds)
         if args.to_csv:
-            self.to_csv(outname+'.csv', extra_columns, skip_time)    
+            self.to_csv(outname+'.csv', extra_columns, skip_time, **bounds)    
         if args.to_pcp:
-            self.to_parallel_coordinate_plot(outname+'_parallel_coordinate_plot.html', extra_columns, skip_time)   
+            self.to_parallel_coordinate_plot(outname+'_parallel_coordinate_plot.html',
+                                             extra_columns, skip_time, **bounds)   
         if args.to_mlflow:
-            self.to_mlflow(extra_columns, skip_time)    
+            self.to_mlflow(extra_columns, skip_time, **bounds)    
 
     def filter_invalid_datasets(self, datasets, proj_name):
         filtered_datasets = []
@@ -309,7 +350,6 @@ class HPOTaskHandle(HPOReport):
         return filtered_datasets
 
     def extract_metadata(self, dataset):
-        #set_trace()
         metadata_list = []
         if 'jobs_metadata' in dataset:
             jobs_metadata = dataset['jobs_metadata']
