@@ -75,13 +75,17 @@ class SteeringIDDS():
             args = parser.parse_args(sys.argv[2:])
         else:
             args = parser.parse_args(sys.argv[1:])
-        self.generate_points(**vars(args))
+        self.run_generator(**vars(args))
 
     def validate_idds_input(self, idds_input):
         '''
-        {"points": [[{hyperparameter_point_1}, loss_or_None], ..., [{hyperparameter_point_N}, loss_or_None]], "opt_space": <opt space>}
+        old format
+        {"points": [[{hyperparameter_point_1}, <loss_or_None>], ..., [{hyperparameter_point_N}, <loss_or_None>]], "opt_space": <opt space>}
+        new format
+        {"points": [[<model_id_1>, {hyperparameter_point_1}, <loss_or_None>], ..., [<model_id_N>, {hyperparameter_point_N}, <loss_or_None>]], "opt_space": ["model_id": <model_id>, "search_space": <search_space>]}
         '''
-        keys = ['points']
+        keys = ['points', 'opt_space']
+        # check main keys
         for key in keys:
             if key not in idds_input:
                 raise KeyError('Key {} not found in idds input.'
@@ -92,46 +96,73 @@ class SteeringIDDS():
         for point in idds_input['points']:
             if not isinstance(point, List):
                 raise ValueError('idds should have the data structure: Dict[List[List[...]]]')
-            if not isinstance(point[0], Dict):
-                raise ValueError('idds should have the data structure: Dict[List[List[Dict, Value]]]')
-        return True
+            if not isinstance(point[0], (Dict, int)):
+                raise ValueError('idds should have the data structure: Dict[List[List[Dict, Value]]] or Dict[List[List[int, Dict, Value]]]')
+        # old format
+        if isinstance(idds_input['opt_space'], Dict):
+            return 1
+        # new format
+        elif isinstance(idds_input['opt_space'], List):
+            for search_space in idds_input['opt_space']:
+                if not isinstance(search_space, Dict):
+                    raise ValueError('idds search space should be a dictionary not {}'.format(type(search_space)))
+            return 2
+        else:
+            raise ValueError('invalid format for idds opt_space')
 
     def parse_idds_input(self, file):
         if not file:
-            return None, None, None
-        points = []
-        results = []
-        search_space = None
+            return None
 
         with open(file,'r') as input_file:
             idds_data = json.load(input_file)
-        self.validate_idds_input(idds_data)
+            
+        idds_format = self.validate_idds_input(idds_data)
         
-        input_data = idds_data['points']
-        for data in input_data:
-            if data[1]:
-                points.append(data[0])
-                results.append(data[1])
-
-
-        search_space = None if 'opt_space' not in idds_data else idds_data['opt_space']
-
-        return points, results, search_space
-
-    def generate_points(self, space, n_point, metric=kDefaultMetric, mode=kDefaultMode,
-        lib=kDefaultGenerator, max_point=None, infile=None, outfile=None, **args):
-        points, results, idds_search_space = self.parse_idds_input(infile)
-
-        # load search space
-        if (not space) and (not idds_search_space):
+        # old format
+        if idds_format == 1:
+            points = []
+            results = []
+            input_data = idds_data['points']
+            for data in input_data:
+                point, result = data[0], data[1]
+                if result is not None:
+                    points.append(point)
+                    results.append(result)
+            search_space = idds_data.get('opt_space', None)
+            return (points, results, search_space)
+        
+        elif idds_format == 2:
+            model_results = {}
+            for opt_space in idds_data.get('opt_space', []):
+                model_id = opt_space.get('model_id', None)
+                search_space = opt_space.get('search_space', None)
+                if model_id is None:
+                    raise ValueError('Cannot extract model id from idds opt space')
+                model_results[model_id] = {}
+                model_results[model_id]['search_space'] = search_space
+                model_results[model_id]['points'] = []
+                model_results[model_id]['results'] = []
+            for data in idds_data.get('points', []):
+                model_id = data[0]
+                if model_id not in model_results:
+                    raise ValueError('missing search space definition for model id: {}'.format(model_id))
+                point, result = data[1], data[2]
+                if result is not None:
+                    model_results[model_id]['points'].append(point)
+                    model_results[model_id]['results'].append(result)
+            return model_results
+        else:
+            raise RuntimeError('Failed to parse idds input')
+    
+    def generate_points(self, search_space, n_point, metric=kDefaultMetric, mode=kDefaultMode,
+                            lib=kDefaultGenerator, max_point=None, points=None,
+                            results=None, **args):
+        
+        if not search_space:
             raise RuntimeError('search space is not specified in either idds input or '
             'through command line argument')
-        if idds_search_space:
-            search_space = idds_search_space            
-        if space:
-            with open(space, 'r') as space_input:
-                search_space = json.load(space_input)
-
+        
         # create generator
         generator = self.get_generator(search_space, metric, mode, lib, **args)
 
@@ -157,9 +188,42 @@ class SteeringIDDS():
         print('INFO: Generated {} new points'.format(n_generate))
         generator.show(new_points)
 
+        return new_points
+
+    def run_generator(self, space, n_point, metric=kDefaultMetric,
+                      mode=kDefaultMode, lib=kDefaultGenerator, max_point=None,
+                      infile=None, outfile=None, **args):
+        
+        parsed_data = self.parse_idds_input(infile)
+        
+        # case no input points
+        if parsed_data is None:
+            if not space:
+                raise ValueError('search space can not be empty')
+            with open(space, 'r') as space_input:
+                search_space = json.load(space_input)
+            new_points = self.generate_points(search_space=search_space, n_point=n_point,
+                                             metric=metric, mode=mode,
+                                             lib=lib, max_point=max_point, **args)
+        # old format
+        elif isinstance(parsed_data, tuple):
+            points, results, search_space = parsed_data[0], parsed_data[1], parsed_data[2]
+            new_points = self.generate_points(search_space=search_space, n_point=n_point,
+                                             metric=metric, mode=mode,
+                                             lib=lib, max_point=max_point, 
+                                             points=points, results=results, **args)
+        elif isinstance(parsed_data, dict):
+            new_points = []
+            for model_id in parsed_data:
+                data = parsed_data[model_id]
+                points, results, search_space = data["points"], data["results"], data["search_space"]
+                model_specific_new_points = self.generate_points(search_space=search_space, n_point=n_point,
+                                                                metric=metric, mode=mode,
+                                                                lib=lib, max_point=max_point, 
+                                                                points=points, results=results, **args)
+                new_points[model_id].append(tuple([model_id, model_specific_new_points]))
+
         # save output
         if outfile:
             with open(outfile, 'w') as out:
-                json.dump(new_points, out, indent=2, cls=NpEncoder)
-
-
+                json.dump(new_points, out, indent=2, cls=NpEncoder)
\ No newline at end of file
