@@ -59,7 +59,10 @@ class GridSiteInfo():
             jsonfileLocation = os.environ['ALRB_cvmfs_repo'] + '/sw/local/etc/agis_schedconf.json'
         except:
             jsonfileLocation = '/cvmfs/atlas.cern.ch/repo/sw/local/etc/agis_schedconf.json'
-
+        
+        if not os.path.exists(jsonfileLocation):
+            raise ValueError('cannot locate file containing grid site information: agis_schedconf.json')
+            
         with open(jsonfileLocation,'r') as jsonfile:
             jsondata = json.load(jsonfile)
 
